@@ -1,21 +1,22 @@
-import warnings
+from __future__ import annotations
+
 import collections.abc
+import warnings
 from collections import OrderedDict, namedtuple
-import mplhep._deprecate as deprecate
-from typing import Union, List, Optional, Dict, Any, TYPE_CHECKING
+from typing import TYPE_CHECKING, Any, Union
 
 import matplotlib as mpl
 import matplotlib.pyplot as plt
 import numpy as np
-from matplotlib.transforms import Bbox
 from matplotlib.offsetbox import AnchoredText
-from mpl_toolkits.axes_grid1 import make_axes_locatable, axes_size
+from matplotlib.transforms import Bbox
+from mpl_toolkits.axes_grid1 import axes_size, make_axes_locatable
 
 from .utils import (
     get_histogram_axes_title,
-    process_histogram_parts,
     get_plottable_protocol_bins,
     hist_object_handler,
+    process_histogram_parts,
 )
 
 if TYPE_CHECKING:
@@ -30,9 +31,7 @@ Hist1DArtists = Union[StairsArtists, ErrorBarArtists]
 Hist2DArtists = ColormeshArtists
 
 
-def get_density(
-    h, density: bool = True, binwnorm: Optional[float] = None, *, bins, hists
-):
+def get_density(h, density: bool = True, binwnorm: float | None = None, *, bins, hists):
     if density and binwnorm is not None:
         raise ValueError("Can only calculate density or binwnorm")
     per_hist_norm = np.sum(h, axis=(1 if h.ndim > 1 else 0))
@@ -56,11 +55,17 @@ def get_stack(_h, hists):
 
 def soft_update_kwargs(kwargs, mods, rc=True):
     not_default = [k for k, v in mpl.rcParamsDefault.items() if v != mpl.rcParams[k]]
-    aliases = {"ls": "linestyle"}
+    respect = [
+        "hatch.linewidth",
+        "lines.linewidth",
+        "patch.linewidth",
+        "lines.linestyle",
+    ]
+    aliases = {"ls": "linestyle", "lw": "linewidth"}
     kwargs = {aliases[k] if k in aliases else k: v for k, v in kwargs.items()}
     for key, val in mods.items():
         rc_modded = (key in not_default) or (
-            key in [k.split(".")[-1] for k in not_default]
+            key in [k.split(".")[-1] for k in not_default if k in respect]
         )
         if key not in kwargs and (rc and not rc_modded):
             kwargs[key] = val
@@ -73,7 +78,7 @@ def histplot(
     H,  # Histogram object, tuple or array
     bins=None,  # Bins to be supplied when h is a value array or iterable of arrays
     *,
-    yerr: "ArrayLike | bool | None" = None,
+    yerr: ArrayLike | bool | None = None,
     w2=None,
     w2method=None,
     stack=False,
@@ -180,7 +185,7 @@ def histplot(
     if w2 is not None and yerr is not None:
         raise ValueError("Can only supply errors or w2")
 
-    _labels: List[Optional[str]]
+    _labels: list[str | None]
     if label is None:
         _labels = [None] * len(hists)
     elif isinstance(label, str):
@@ -193,7 +198,7 @@ def histplot(
     def iterable_not_string(arg):
         return isinstance(arg, collections.abc.Iterable) and not isinstance(arg, str)
 
-    _chunked_kwargs: List[Dict[str, Any]] = []
+    _chunked_kwargs: list[dict[str, Any]] = []
     for _i in range(len(hists)):
         _chunked_kwargs.append({})
     for kwarg in kwargs:
@@ -215,7 +220,7 @@ def histplot(
 
     ############################
     # yerr calculation
-    _yerr: "np.ndarray | None"
+    _yerr: np.ndarray | None
     if yerr is not None:
         # yerr is array
         if hasattr(yerr, "__len__"):
@@ -317,12 +322,12 @@ def histplot(
 
     ##########
     # Plotting
-    return_artists: List[Union[StairsArtists, ErrorBarArtists]] = []
+    return_artists: list[StairsArtists | ErrorBarArtists] = []
     if histtype == "step":
         for i in range(len(hists)):
             _kwargs = _chunked_kwargs[i]
             _label = _labels[i]
-            _step_label = _label if yerr is None else None
+            _step_label = _label if (yerr is None and w2 is None) else None
             _kwargs = soft_update_kwargs(_kwargs, {"linewidth": 1.5})
 
             _s = ax.stairs(
@@ -369,7 +374,7 @@ def histplot(
             "markersize": 10.0,
             "elinewidth": 1,
         }
-        _yerri: Optional[List[float]]
+        _yerri: list[float] | None
         if xerr is True:
             _xerr = _bin_widths / 2
         elif isinstance(xerr, (int, float)):
@@ -862,7 +867,7 @@ def sort_legend(ax, order=None):
     elif order is None:
         ordered_label_list = labels
     else:
-        raise TypeError("Unexpected values type of order: {}".format(type(order)))
+        raise TypeError(f"Unexpected values type of order: {type(order)}")
 
     ordered_label_list = [entry for entry in ordered_label_list if entry in labels]
     ordered_label_values = [by_label[k] for k in ordered_label_list]
@@ -892,7 +897,7 @@ def save_variations(fig, name, text_list=None, exp=None):
     if text_list is None:
         text_list = ["Preliminary", ""]
 
-    from mplhep.label import ExpText, ExpSuffix
+    from mplhep.label import ExpSuffix, ExpText
 
     for text in text_list:
         for ax in fig.get_axes():
